@@ -29,11 +29,10 @@ class MultilingualStringField(BaseField):
             if isinstance(value, Mapping):
                 value = MultilingualString(value)
             elif isinstance(value, basestring):
-                old_value = instance._data.get('name')
-
-                if old_value:
-                    old_value.translations[old_value.language] = value
-                    value = old_value
+                old_value = instance._data.get(self.db_field)
+                # @todo: improve MultilingualString to handle updates
+                old_value.translations[old_value.language] = value
+                value = old_value.translate(old_value.language)
 
         super(MultilingualStringField, self).__set__(instance, value)
 
@@ -42,4 +41,6 @@ class MultilingualStringField(BaseField):
         if not hasattr(instance, 'translate'):
             owner.translate = _translate
 
-        return super(MultilingualStringField, self).__get__(instance, owner)
+        return (
+            super(MultilingualStringField, self).__get__(instance, owner) or
+            MultilingualString())
